@@ -52,12 +52,17 @@ def check_access_account(view_id: str, adscale_key):
     scopes = ['https://www.googleapis.com/auth/analytics.readonly']
     credentials = service_account.Credentials.from_service_account_file(adscale_key, scopes=scopes)
     service = build('analytics', 'v3', credentials=credentials)
-    try : 
+    if 'ga:' in view_id:
+        view_id = view_id.replace('ga:', '')
+    try:
         views = service.management().profiles().list(accountId='~all', webPropertyId='~all').execute()
     except HttpError as err:
         print(err)
         raise ValueError(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+
+    if view_id not in [view.get('id') for view in views.get('items', [])]:
+        raise ValueError(F"We cannot access your view with the id: {view_id}. Are you sure you granted access and entered correct ID?")
+
     for view in views.get('items', []):
         if view.get('id') == view_id:
             return view.get('name')
-    
\ No newline at end of file
